
# Linux archive.
LINUX_ARCH = https://ftp-trace.ncbi.nlm.nih.gov/sra/sdk/3.0.0/sratoolkit.3.0.0-ubuntu64.tar.gz

# MacOS archive.
MACOS_ARCH = https://ftp-trace.ncbi.nlm.nih.gov/sra/sdk/3.0.0/sratoolkit.3.0.0-mac64.tar.gz

.PHONY: install

# Detect the OS.
UNAME_S := $(shell uname -s)

# Select download URL based on platform.
ifeq (${UNAME_S},Linux)
	URL = ${LINUX_ARCH}
	DIR = sratoolkit.3.0.0-ubuntu64
else
	URL = ${MACOS_ARCH}
	DIR = sratoolkit.3.0.0-mac64
endif

# The home bin directory.
BIN = ~/bin

# The name of the archive.
FNAME = $(notdir ${URL})

# The full name of the archive.
DNAME = ${BIN}/${FNAME}

# The directpry name.
DIR = $(basename $(basename ${FNAME}))

# The fastq-dump executable.
FASTQ_DUMP = ${BIN}/${DIR}/bin/fastq-dump

# Initialization script
INIT = ~/.biostar_handbook

all:
	@echo "run make install "
	@echo ""
	@echo "URL=${URL}"
	@echo "DIR=${DIR}"
	@echo "INIT=${INIT}"
	@echo "FASTQ_DUMP=${FASTQ_DUMP}"
	@echo ""

# Downloads the archive.
${DNAME}:
	mkdir -p ${BIN}
	@echo "#"
	@echo "# downloading sratools}"
	@echo "#"
	(cd ${BIN} && curl -L -o ${FNAME} ${URL})

# fastq-dump to be installed.
${FASTQ_DUMP}: ${DNAME}
	(cd ${BIN} && tar xzvf ${FNAME})
	(cd ${BIN} && find ${DIR}	-type f -exec touch {} \;)

# Create the initialization script.
${INIT}: ${FASTQ_DUMP}
	@echo export PATH=~/bin/${DIR}/bin:'$$PATH' > ${INIT}

# Source line
LINE = source ~/.biostar_handbook

# Installs the archive.
install: ${INIT}
	@if ! grep -q '${LINE}' ~/.bash_profile; then echo '${LINE}' >> ~/.bash_profile; fi
	@echo "#"
	@echo "# ${INIT}"
	@echo "#"
	@echo "# sratools installation complete"
	@echo "#"
	@echo "# restart the terminal or: source ~/.bash_profile"
	@echo "#"

